@@ -499,7 +499,14 @@ def ParseCreateOptionsBase(
       containerd_config_from_file=get_default('containerd_config_from_file'),
       fleet_project=get_default('fleet_project'),
       enable_fleet=get_default('enable_fleet'),
+      membership_type=get_default('membership_type'),
       enable_secret_manager=get_default('enable_secret_manager'),
+      enable_secret_manager_rotation=get_default(
+          'enable_secret_manager_rotation'
+      ),
+      secret_manager_rotation_interval=get_default(
+          'secret_manager_rotation_interval'
+      ),
       enable_cilium_clusterwide_network_policy=get_default(
           'enable_cilium_clusterwide_network_policy'
       ),
@@ -551,8 +558,13 @@ def ParseCreateOptionsBase(
       enable_legacy_lustre_port=get_default('enable_legacy_lustre_port'),
       enable_default_compute_class=get_default('enable_default_compute_class'),
       enable_k8s_certs_via_dns=get_default('enable_k8s_certs_via_dns'),
-  )
 
+      boot_disk_provisioned_iops=get_default('boot_disk_provisioned_iops'),
+      boot_disk_provisioned_throughput=get_default(
+          'boot_disk_provisioned_throughput'
+      ),
+      network_tier=get_default('network_tier'),
+  )
 
 GA = 'ga'
 BETA = 'beta'
@@ -642,6 +654,7 @@ flags_to_add = {
             p, release_track=base.ReleaseTrack.GA
         ),
         'bootdiskkms': flags.AddBootDiskKmsKeyFlag,
+        'bootdisk': flags.AddBootDiskConfigFlags,
         'cloudlogging': flags.AddEnableCloudLogging,
         'cloudmonitoring': flags.AddEnableCloudMonitoring,
         'cloudrunalpha': flags.AddEnableCloudRunAlphaFlag,
@@ -763,7 +776,7 @@ flags_to_add = {
         ),
         'containerdConfig': flags.AddContainerdConfigFlag,
         'secretManagerConfig': lambda p: flags.AddSecretManagerEnableFlagGroup(
-            p, release_track=base.ReleaseTrack.GA
+            p, hidden=True
         ),
         'InTransitEncryption': flags.AddInTransitEncryptionFlag,
         'enableCiliumClusterwideNetworkPolicy': (
@@ -794,11 +807,12 @@ flags_to_add = {
         'anonymousAuthenticationConfig': (
             flags.AddAnonymousAuthenticationConfigFlag
         ),
-        'enableAutoIpam': lambda p: flags.AddAutoIpamFlag(p, hidden=True),
+        'enableAutoIpam': flags.AddAutoIpamFlag,
         'enableK8sTokensViaDns': flags.AddEnableK8sTokensViaDnsFlag,
         'enableLegacyLustrePort': flags.AddEnableLegacyLustrePortFlag,
         'enableDefaultComputeClass': flags.AddEnableDefaultComputeClassFlag,
         'enableK8sCertsViaDns': flags.AddEnableK8sCertsViaDnsFlag,
+        'networkTier': flags.AddNetworkTierFlag,
     },
     BETA: {
         'accelerator': lambda p: AddAcceleratorFlag(p, True, True, True, True),
@@ -817,6 +831,7 @@ flags_to_add = {
             p, release_track=base.ReleaseTrack.BETA
         ),
         'bootdiskkms': flags.AddBootDiskKmsKeyFlag,
+        'bootdisk': flags.AddBootDiskConfigFlags,
         'cloudlogging': flags.AddEnableCloudLogging,
         'cloudmonitoring': flags.AddEnableCloudMonitoring,
         'cloudrunalpha': flags.AddEnableCloudRunAlphaFlag,
@@ -944,6 +959,7 @@ flags_to_add = {
         'enableGoogleCloudAccess': flags.AddEnableGoogleCloudAccess,
         'managedConfig': flags.AddManagedConfigFlag,
         'fleetProject': flags.AddFleetProjectFlag,
+        'membershipType': flags.AddMembershipTypeFlags,
         'loggingvariant': flags.AddLoggingVariantFlag,
         'enableMultiNetworking': flags.AddEnableMultiNetworkingFlag,
         'enableSecurityPosture': flags.AddSecurityPostureFlag,
@@ -964,9 +980,7 @@ flags_to_add = {
         'enableFqdnNetworkPolicy': flags.AddEnableFqdnNetworkPolicyFlag,
         'InTransitEncryption': flags.AddInTransitEncryptionFlag,
         'containerdConfig': flags.AddContainerdConfigFlag,
-        'secretManagerConfig': lambda p: flags.AddSecretManagerEnableFlagGroup(
-            p, release_track=base.ReleaseTrack.BETA
-        ),
+        'secretManagerConfig': flags.AddSecretManagerEnableFlagGroup,
         'enableCiliumClusterwideNetworkPolicy': (
             flags.AddEnableCiliumClusterwideNetworkPolicyFlag
         ),
@@ -991,11 +1005,12 @@ flags_to_add = {
         'anonymousAuthenticationConfig': (
             flags.AddAnonymousAuthenticationConfigFlag
         ),
-        'enableAutoIpam': lambda p: flags.AddAutoIpamFlag(p, hidden=True),
+        'enableAutoIpam': flags.AddAutoIpamFlag,
         'enableK8sTokensViaDns': flags.AddEnableK8sTokensViaDnsFlag,
         'enableLegacyLustrePort': flags.AddEnableLegacyLustrePortFlag,
         'enableDefaultComputeClass': flags.AddEnableDefaultComputeClassFlag,
         'enableK8sCertsViaDns': flags.AddEnableK8sCertsViaDnsFlag,
+        'networkTier': flags.AddNetworkTierFlag,
     },
     ALPHA: {
         'accelerator': lambda p: AddAcceleratorFlag(p, True, True, True, True),
@@ -1017,6 +1032,7 @@ flags_to_add = {
             p, release_track=base.ReleaseTrack.ALPHA
         ),
         'bootdiskkms': flags.AddBootDiskKmsKeyFlag,
+        'bootdisk': flags.AddBootDiskConfigFlags,
         'cloudmonitoring': flags.AddEnableCloudMonitoring,
         'cloudrunalpha': flags.AddEnableCloudRunAlphaFlag,
         'cloudrunconfig': flags.AddCloudRunConfigFlag,
@@ -1115,7 +1131,9 @@ flags_to_add = {
         'spot': flags.AddSpotFlag,
         'stackdriver': flags.AddEnableStackdriverKubernetesFlag,
         'securityprofile': flags.AddSecurityProfileForCreateFlags,
-        'stacktype': flags.AddStackTypeFlag,
+        'stacktype': lambda p: flags.AddStackTypeFlag(
+            p, release_track=base.ReleaseTrack.ALPHA
+        ),
         'storagePools': flags.AddStoragePoolsFlag,
         'localSsdEncryptionMode': flags.AddLocalSsdEncryptionModeFlag,
         'dataCacheCount': flags.AddDataCacheCountFlag,
@@ -1147,6 +1165,7 @@ flags_to_add = {
         'enableGoogleCloudAccess': flags.AddEnableGoogleCloudAccess,
         'managedConfig': flags.AddManagedConfigFlag,
         'fleetProject': flags.AddFleetProjectFlag,
+        'membershipType': flags.AddMembershipTypeFlags,
         'loggingvariant': flags.AddLoggingVariantFlag,
         'enableMultiNetworking': flags.AddEnableMultiNetworkingFlag,
         'enableSecurityPosture': flags.AddSecurityPostureFlag,
@@ -1167,9 +1186,7 @@ flags_to_add = {
         'enableFqdnNetworkPolicy': flags.AddEnableFqdnNetworkPolicyFlag,
         'InTransitEncryption': flags.AddInTransitEncryptionFlag,
         'containerdConfig': flags.AddContainerdConfigFlag,
-        'secretManagerConfig': lambda p: flags.AddSecretManagerEnableFlagGroup(
-            p, release_track=base.ReleaseTrack.ALPHA
-        ),
+        'secretManagerConfig': flags.AddSecretManagerEnableFlagGroup,
         'enableCiliumClusterwideNetworkPolicy': (
             flags.AddEnableCiliumClusterwideNetworkPolicyFlag
         ),
@@ -1194,11 +1211,12 @@ flags_to_add = {
         'anonymousAuthenticationConfig': (
             flags.AddAnonymousAuthenticationConfigFlag
         ),
-        'enableAutoIpam': lambda p: flags.AddAutoIpamFlag(p, hidden=True),
+        'enableAutoIpam': flags.AddAutoIpamFlag,
         'enableK8sTokensViaDns': flags.AddEnableK8sTokensViaDnsFlag,
         'enableLegacyLustrePort': flags.AddEnableLegacyLustrePortFlag,
         'enableDefaultComputeClass': flags.AddEnableDefaultComputeClassFlag,
         'enableK8sCertsViaDns': flags.AddEnableK8sCertsViaDnsFlag,
+        'networkTier': flags.AddNetworkTierFlag,
     },
 }
 
@@ -1500,6 +1518,7 @@ class CreateBeta(Create):
     ops.managed_config = get_default('managed_config')
     ops.fleet_project = get_default('fleet_project')
     ops.enable_fleet = get_default('enable_fleet')
+    ops.membership_type = get_default('membership_type')
     ops.enable_multi_networking = get_default('enable_multi_networking')
     ops.compliance = get_default('compliance')
     ops.compliance_standards = get_default('compliance_standards')
@@ -1661,6 +1680,7 @@ class CreateAlpha(Create):
     ops.managed_config = get_default('managed_config')
     ops.fleet_project = get_default('fleet_project')
     ops.enable_fleet = get_default('enable_fleet')
+    ops.membership_type = get_default('membership_type')
     ops.enable_multi_networking = get_default('enable_multi_networking')
     ops.compliance = get_default('compliance')
     ops.compliance_standards = get_default('compliance_standards')
